<?php

namespace Modules\Cotacao\Modules\Pedido\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Message;
use Modules\Cotacao\Modules\Pedido\Services\Sup09600IImportacaodeRFPService;
use Zeedhi\Framework\Report\ReportService;

class Sup09600IImportacaodeRFPController extends \Zeedhi\Framework\Controller\Report
{
    protected $newCode;
    protected $environment;
    protected $result;
    protected $errors = array();
    protected $errorMessages = array();
    protected $reportMapping = array ();
    protected $qr2Strategy;
	protected $stNomeRel;
    protected $stExtensao;
    protected $birtStrategy;

    public function __construct($reportService, $newCode, $environment, Sup09600IImportacaodeRFPService $service, $qr2Strategy, $birtStrategy)
    {
        parent::__construct($reportService);
        $this->newCode       = $newCode;
        $this->environment   = $environment;
        $this->service       = $service;
        $this->qr2Strategy = $qr2Strategy;
        $this->birtStrategy = $birtStrategy;
    }

    public function importarXlsRFB(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $table = $this->service->xlsReadInsert($row, $request);
            $response->addDataSet(new DataSet('data', $table));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function checkItens(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $nrRFPMain = $this->service->searchNRRFPMAIN($row);
            $this->service->execCheckImportProcedure($nrRFPMain);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getNrRfpmain(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $nrRFPMain = $this->service->getNrRfpmain($row);
            if($row['REPORT'] === 'SUP09600.BIRT'){
                $checkItens = $this->service->checkItensImportados($nrRFPMain);
                $response->addDataSet(new DataSet("NRRFPMAIN", [$nrRFPMain, $checkItens]));
            } else if($row['REPORT'] === 'SUP09601.BIRT'){
                $checkCritcas = $this->service->checkCriticas($nrRFPMain);
                $response->addDataSet(new DataSet("NRRFPMAIN", [$nrRFPMain, $checkCritcas]));
            }
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteImport(DTO\Request $request, DTO\Response $response)
    {
        try {
            $conditions = $request->getRow();
            $this->service->deleteImport($conditions);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    public function gerarPedido(DTO\Request $request, DTO\Response $response)
    {
        $conditions = $request->getRow();

        $params = array(
            "NRRFPMAIN" => $conditions["NRRFPMAIN"],
            "IDDISMONTLIS" => $conditions["IDDISMONTLIS"]
        );
        try {
            $result = $this->service->execImportaRFPProcedure($params);

            if (isset($result['ERROR'])) {
                throw new \Exception($result['ERROR']);
            }

            if (isset($result['MESSAGE'])) {
                $response->addMessage(new Message($result['MESSAGE']));
            }
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        $row["DTVALIDADEINICIAL"] = $row["DTVALIDADE"]["formattedStart"];
        $row["DTVALIDADEFINAL"] = $row["DTVALIDADE"]["formattedEnd"];
        $row["DTIMPINIAL"] = $row["DTIMPORTACAO"]["formattedStart"];
        $row["DTIMPFINAL"] = $row["DTIMPORTACAO"]["formattedEnd"];
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
        $this->stNomeRel = $this->getReportName($row);
        $row['NRORG'] = $this->environment->getNrOrg();
        $this->reportMapping[$this->stNomeRel] =
        array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
                "NRRFPMAIN"         => "NRRFPMAIN",
                "CDCOMPRADOR"       => "COMPRADOR",
                "NMCOMPRADOR"       => "NMCOMPRADOR",
                "NRINSJURFORN"      => "NRINSJURFORN",
                "NMFANTFORN"        => "NMFANTFORN",
                "CDREGIAO"          => "CDREGIAO",   
                "NMREGIAO"          => "NMREGIAO" , 
                "DTVALIDADEINICIAL" => "DTVALIDADEINICIAL",
                "DTVALIDADEFINAL"   => "DTVALIDADEFINAL",
                "DTIMPINIAL"        => "DTIMPINIAL",
                "DTIMPFINAL"        => "DTIMPFINAL",
                "NRORG"             => "NRORG"                 
            ),
        );
  
    }
}
